@@ -1,6 +1,7 @@
 import sys
 from dev import create_dependencies
 import PyColors
+from . import environshell
 
 
 
@@ -51,7 +52,10 @@ elif sys.argv[1] == "vdict":
 
 
 elif sys.argv[1] == "--version":
-    fetch()
+    fetch('version')
+
+elif sys.argv[1] == "shell":
+    environshell.prompt()
 
 
 else:
